import { create } from "zustand";
import { sendContactFormRequest } from "../api/contactForm";
import { getMessageFromFetchError } from "../utils/backendMessageHandler";

const initialState = {
  isModalOpen: true,
  isSubmitDisabled: false,
  nameField: "",
  phoneNumberField: "",
  telegramField: "",
  whatsappField: "",
};

export const useContactFormStore = create()((set, get) => initialState);

export const setIsContactFormOpen = (isModalOpen) => useContactFormStore.setState({ isModalOpen });
export const setContactFormNameField = (nameField) => useContactFormStore.setState({ nameField });
export const setContactFormTelegramField = (telegramField) => useContactFormStore.setState({ telegramField });
export const setIsSubmitDisabled = (isSubmitDisabled) => useContactFormStore.setState({ isSubmitDisabled });
export const setContactFormPhoneNumberField = (phoneNumberField) => {
  if (/^\+?\d*$/.test(phoneNumberField)) useContactFormStore.setState({ phoneNumberField });
};
export const setContactFormWhatsappField = (whatsappField) => {
  if (/^\+?\d*$/.test(whatsappField)) useContactFormStore.setState({ whatsappField });
};

export const sendContactForm = async () => {
  const { nameField, phoneNumberField, telegramField, whatsappField } = useContactFormStore.getState();

  if (!nameField) return "Имя не указано";
  if (!phoneNumberField && !telegramField && !whatsappField) return "Ни один из контактов не указан";
  if (phoneNumberField && !/^\+\d{5,}|\d{6,}$/.test(phoneNumberField))
    return "Номер телефона должен содержать минимум 6 символов";
  if (whatsappField && !/^\+\d{5,}|\d{6,}$/.test(whatsappField))
    return "Номер Whatsapp должен содержать минимум 6 символов";

  let contact = `phonenumber:${phoneNumberField}`;
  if (telegramField) contact += `\ntelegram:${telegramField}`;
  if (whatsappField) contact += `\nwhatsapp:${whatsappField}`;

  try {
    useContactFormStore.setState({ isSubmitDisabled: true });
    const response = await sendContactFormRequest({
      contact,
      whoami: nameField,
    });

    if (response.status !== 200) throw new Error(response.statusText);

    useContactFormStore.setState({ ...initialState });

    return "Данные отправлены";
  } catch (error) {
    useContactFormStore.setState({ isSubmitDisabled: false });
    return getMessageFromFetchError(error);
  }
};
