import { isAxiosError } from "axios";

import { backendErrorMessage, BackendErrorMessage } from "../__mocks__/backendErrorMessage";

const unknownErrorMessage = "Что-то пошло не так. Повторите попытку позже";

type FetchError = {
  response?: {
    data?: {
      message?: keyof BackendErrorMessage;
    };
  };
  message?: string;
  code?: string;
};

export function getMessageFromFetchError(error: FetchError): string {
  if (process.env.NODE_ENV !== "production") console.log(error);

  const messageKey = error.response?.data?.message;

  if (messageKey && backendErrorMessage.hasOwnProperty(messageKey)) {
    return backendErrorMessage[messageKey];
  }

  if (error.message === "Failed to fetch") return "Ошибка сети";

  if (isAxiosError(error)) {
    switch (error.code) {
      case "ERR_NETWORK":
        return "Ошибка сети";
      case "ERR_CANCELED":
        return "";
      default:
        return "Ошибка сети";
    }
  }

  return unknownErrorMessage;
}
